@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # :copyright: (c) 2021 by Pavlo Dmytrenko.
 # :license: MIT, see LICENSE for more details.
 
@@ -9,11 +7,13 @@ yaspin.base_spinner
 
 Spinner class, used to construct other spinners.
 """
+from dataclasses import dataclass
 
-from __future__ import absolute_import
 
-from collections import namedtuple
+@dataclass
+class Spinner:
+    frames: str
+    interval: int
 
 
-Spinner = namedtuple("Spinner", "frames interval")
 default_spinner = Spinner("⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏", 80)
